@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIImageset.h
 	created:	21/2/2004
 	author:		Paul D Turner
 	
 	purpose:	Defines the interface for the Imageset class
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIImageset_h_
 #define _CEGUIImageset_h_
 
@@ -33,6 +37,7 @@
 #include "CEGUIImagesetManager.h"
 #include "CEGUIImage.h"
 #include "CEGUIIteratorBase.h"
+#include "CEGUIXMLSerializer.h" 
 
 #include <map>
 
@@ -59,7 +64,7 @@ class CEGUIEXPORT Imageset
 {
 	friend class Imageset_xmlHandler;
 private:
-	typedef	std::map<String, Image>	ImageRegistry;
+	typedef	std::map<String, Image, String::FastLessCompare>	ImageRegistry;
 
 	/*************************************************************************
 		Friends to allow access to constructors and destructors
@@ -211,7 +216,6 @@ public:
 	*/
 	void	undefineImage(const String& name);
 
-
 	/*!
 	\brief
 		Removes the definitions for all Image objects currently defined in the Imageset
@@ -501,11 +505,37 @@ public:
     \param out_stream
         Stream where xml data should be output.
 
+    \param indentLevel
+        Current XML indentation level
+
     \return
         Nothing.
     */
-    void writeXMLToStream(OutStream& out_stream) const;
+    void writeXMLToStream(XMLSerializer& xml_stream) const;
 
+    /*!
+    \brief
+        Sets the default resource group to be used when loading imageset data
+
+    \param resourceGroup
+        String describing the default resource group identifier to be used.
+
+    \return
+        Nothing.
+    */
+    static void setDefaultResourceGroup(const String& resourceGroup)
+        { d_defaultResourceGroup = resourceGroup; }
+
+    /*!
+    \brief
+        Returns the default resource group currently set for Imagesets.
+
+    \return
+        String describing the default resource group identifier that will be
+        used when loading Imageset data.
+    */
+    static const String& getDefaultResourceGroup()
+        { return d_defaultResourceGroup; }
 
 protected:
 	/*************************************************************************
@@ -581,6 +611,7 @@ protected:
 	float	d_vertScaling;			//!< current vertical scaling factor.
 	float	d_nativeHorzRes;		//!< native horizontal resolution for this Imageset.
 	float	d_nativeVertRes;		//!< native vertical resolution for this Imageset.
+    static String d_defaultResourceGroup;   //!< Default resource group specifically for Imagesets.
 };
 
 } // End of  CEGUI namespace section
