@@ -1,28 +1,32 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIWindowFactoryManager.h
 	created:	22/2/2004
 	author:		Paul D Turner
 	
 	purpose:	Defines interface for WindowFactoryManager class
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #ifndef _CEGUIWindowFactoryManager_h_
 #define _CEGUIWindowFactoryManager_h_
 
@@ -47,6 +51,10 @@ namespace CEGUI
 /*! 
 \brief
 	Class that manages WindowFactory objects
+
+\todo
+    I think we could clean up the mapping stuff a bit. Possibly make it more generic now
+    with the window renderers and all.
 */
 class CEGUIEXPORT WindowFactoryManager : public Singleton<WindowFactoryManager>
 {
@@ -60,6 +68,7 @@ public:
         String  d_windowType;
         String  d_lookName;
         String  d_baseType;
+        String  d_rendererType;
     };
 
     /*!
@@ -119,7 +128,7 @@ public:
 	*/
 	WindowFactoryManager(void)
 	{
-		Logger::getSingleton().logEvent((utf8*)"CEGUI::WindowFactoryManager singleton created");
+		Logger::getSingleton().logEvent("CEGUI::WindowFactoryManager singleton created");
 	}
 
 
@@ -129,33 +138,13 @@ public:
 	*/
 	~WindowFactoryManager(void)
 	{
-		Logger::getSingleton().logEvent((utf8*)"CEGUI::WindowFactoryManager singleton destroyed");
+		Logger::getSingleton().logEvent("CEGUI::WindowFactoryManager singleton destroyed");
 	}
 
 
 	/*************************************************************************
 		Public Interface
 	*************************************************************************/
-	/*!
-	\brief
-		Return singleton WindowFactoryManager object
-
-	\return
-		Singleton WindowFactoryManager object
-	*/
-	static	WindowFactoryManager&	getSingleton(void);
-
-
-	/*!
-	\brief
-		Return pointer to singleton WindowFactoryManager object
-
-	\return
-		Pointer to singleton WindowFactoryManager object
-	*/
-	static	WindowFactoryManager*	getSingletonPtr(void);
-
-
 	/*!
 	\brief
 		Adds a new WindowFactory to the list of registered factories.
@@ -317,10 +306,13 @@ public:
     \param lookName
         The name of the 'look' that will be used by windows of this type.
 
+    \param renderer
+        The type of window renderer to assign for windows of this type.
+
     \return
         Nothing.
     */
-    void addFalagardWindowMapping(const String& newType, const String& targetType, const String& lookName);
+    void addFalagardWindowMapping(const String& newType, const String& targetType, const String& lookName, const String& renderer);
 
     /*!
     \brief
@@ -358,6 +350,19 @@ public:
     */
     const String& getMappedLookForType(const String& type) const;
 
+    /*!
+    \brief
+        Return the name of the WindowRenderer assigned to the specified window mapping.
+
+    \param type
+        Name of a window type.  The window type referenced should be a falagard mapped type.
+
+    \return
+        String object holding the name of the window renderer mapped for the requested type.
+
+    \exception InvalidRequestException thrown if \a type is not a falagard mapping type (or maybe the type didn't exist).
+    */
+    const String& getMappedRendererForType(const String& type) const;
 
     /*!
     \brief
@@ -379,13 +384,27 @@ public:
     */
     String getDereferencedAliasType(const String& type) const;
 
+    /*!
+    \brief
+        Return the FalagardWindowMapping for the specified window mapping \a type.
+
+    \param type
+        Name of a window type.  The window type referenced should be a falagard mapped type.
+
+    \return
+        FalagardWindowMapping object describing the falagard mapping.
+
+    \exception InvalidRequestException thrown if \a type is not a falagard mapping type (or maybe the type didn't exist).
+    */
+    const FalagardWindowMapping& getFalagardMappingForType(const String& type) const;
+
 private:
 	/*************************************************************************
 		Implementation Data
 	*************************************************************************/
-	typedef	std::map<String, WindowFactory*>	WindowFactoryRegistry;		//!< Type used to implement registry of WindowFactory objects
-	typedef std::map<String, AliasTargetStack>	TypeAliasRegistry;		//!< Type used to implement registry of window type aliases.
-    typedef std::map<String, FalagardWindowMapping> FalagardMapRegistry;    //!< Type used to implement registry of falagard window mappings.
+	typedef	std::map<String, WindowFactory*, String::FastLessCompare>	WindowFactoryRegistry;		//!< Type used to implement registry of WindowFactory objects
+	typedef std::map<String, AliasTargetStack, String::FastLessCompare>	TypeAliasRegistry;		//!< Type used to implement registry of window type aliases.
+    typedef std::map<String, FalagardWindowMapping, String::FastLessCompare> FalagardMapRegistry;    //!< Type used to implement registry of falagard window mappings.
 
 	WindowFactoryRegistry	d_factoryRegistry;			//!< The container that forms the WindowFactory registry
 	TypeAliasRegistry		d_aliasRegistry;			//!< The container that forms the window type alias registry.
