@@ -17,8 +17,10 @@ if not CEGUI_CORE_LIBRARY_SOLUTION then
     project.configs =
     {
     	"Debug",
+    	"Debug_Static",
     	"ReleaseWithSymbols",
     	"Release",
+    	"Release_Static"
     }
 end
 
@@ -28,20 +30,23 @@ local pkg_table =
     {
         "common",
         "FirstWindow",
-        "Demo4",
+        "TextDemo",
         "Demo6",
         "Demo7",
+        "DragDropDemo",
         "FalagardDemo1",
         "FontDemo",
         "Minesweeper",
         "ScrollablePaneDemo",
         "TabControlDemo",
+        "TreeDemo"
     }
 }
 
 local lua_samples =
 {
     "Demo8",
+    "InstancedWindows",
 }
 
 if LUA_SCRIPT_MODULE then
