@@ -124,7 +124,10 @@ void FreeTypeFont::load ()
 
     updateFont ();
 
-    snprintf (tmp, sizeof (tmp), "Succsessfully loaded %d glyphs", d_cp_map.size ());
+    snprintf(tmp, sizeof(tmp),
+             "Succsessfully loaded %d glyphs",
+             static_cast<int>(d_cp_map.size()));
+
     Logger::getSingleton ().logEvent (tmp);
 }
 
@@ -152,7 +155,8 @@ uint FreeTypeFont::getTextureSize (CodepointMap::const_iterator s,
                 continue;
 
             // load glyph metrics (don't render)
-            if (FT_Load_Char (d_fontFace, c->first, FT_LOAD_DEFAULT))
+            if (FT_Load_Char(d_fontFace, c->first,
+                             FT_LOAD_DEFAULT | FT_LOAD_FORCE_AUTOHINT))
                 continue;
 
             uint glyph_w = int (ceil (d_fontFace->glyph->metrics.width * FT_POS_COEF)) +
@@ -278,10 +282,13 @@ void FreeTypeFont::rasterize (utf32 start_codepoint, utf32 end_codepoint)
                     drawGlyphToBuffer (mem_buffer + (y * texsize) + x, texsize);
 
                     // Create a new image in the imageset
-                    Rect area (float(x), float(y), float(x + glyph_w - INTER_GLYPH_PAD_SPACE),
-                               float(y + glyph_h - INTER_GLYPH_PAD_SPACE));
-                    Point offset (d_fontFace->glyph->metrics.horiBearingX * float(FT_POS_COEF),
-                                  -d_fontFace->glyph->metrics.horiBearingY * float(FT_POS_COEF));
+                    Rect area(static_cast<float>(x),
+                              static_cast<float>(y),
+                              static_cast<float>(x + glyph_w - INTER_GLYPH_PAD_SPACE),
+                              static_cast<float>(y + glyph_h - INTER_GLYPH_PAD_SPACE));
+
+                    Point offset(d_fontFace->glyph->metrics.horiBearingX * static_cast<float>(FT_POS_COEF),
+                                 -d_fontFace->glyph->metrics.horiBearingY * static_cast<float>(FT_POS_COEF));
 
                     String name;
                     name += s->first;
@@ -469,7 +476,8 @@ void FreeTypeFont::updateFont ()
             max_codepoint = codepoint;
 
         // load-up required glyph metrics (don't render)
-        if (FT_Load_Char (d_fontFace, codepoint, FT_LOAD_DEFAULT))
+        if (FT_Load_Char(d_fontFace, codepoint,
+                         FT_LOAD_DEFAULT | FT_LOAD_FORCE_AUTOHINT))
             continue; // glyph error
 
         float adv = d_fontFace->glyph->metrics.horiAdvance * float(FT_POS_COEF);
