@@ -2,7 +2,7 @@
 	filename: 	CEGUIWindow.cpp
 	created:	21/2/2004
 	author:		Paul D Turner
-	
+
 	purpose:	Implements the Window base class
 *************************************************************************/
 /***************************************************************************
@@ -89,6 +89,7 @@ WindowProperties::UnifiedMaxSize	Window::d_unifiedMaxSizeProperty;
 WindowProperties::MousePassThroughEnabled   Window::d_mousePassThroughEnabledProperty;
 WindowProperties::WindowRenderer    Window::d_windowRendererProperty;
 WindowProperties::LookNFeel         Window::d_lookNFeelProperty;
+WindowProperties::DragDropTarget    Window::d_dragDropTargetProperty;
 
 /*************************************************************************
 	static data definitions
@@ -99,6 +100,7 @@ Window*	Window::d_captureWindow		= 0;
 /*************************************************************************
 	Event name constants
 *************************************************************************/
+const String Window::EventWindowUpdated ( "WindowUpdate" );
 const String Window::EventParentSized( "ParentSized" );
 const String Window::EventSized( "Sized" );
 const String Window::EventMoved( "Moved" );
@@ -180,6 +182,7 @@ Window::Window(const String& type, const String& name) :
     d_wantsMultiClicks  = true;
     d_distCapturedInputs = false;
     d_riseOnClick       = true;
+    d_dragDropTarget    = true;
 
     // initialise mouse button auto-repeat state
     d_repeatButton = NoButton;
@@ -226,7 +229,7 @@ Window::Window(const String& type, const String& name) :
     d_screenUnclippedInnerRectValid = false;
     d_screenRectValid = false;
     d_screenInnerRectValid = false;
-    
+
     d_screenUnclippedRect = Rect(0,0,0,0);
     d_screenUnclippedInnerRect = Rect(0,0,0,0);
     d_screenRect = Rect(0,0,0,0);
@@ -255,7 +258,7 @@ const String& Window::getType(void) const
 
 
 /*************************************************************************
-	return true if the Window is currently disabled	
+	return true if the Window is currently disabled
 *************************************************************************/
 bool Window::isDisabled(bool localOnly) const
 {
@@ -278,7 +281,7 @@ bool Window::isVisible(bool localOnly) const
 
 /*************************************************************************
 	return true if this is the active Window
-	(the window that receives inputs)	
+	(the window that receives inputs)
 *************************************************************************/
 bool Window::isActive(void) const
 {
@@ -378,16 +381,56 @@ Window* Window::getChild(const String& name) const
 
 	for (size_t i = 0; i < child_count; ++i)
 	{
-		if (d_children[i]->getName() == name)
+		String childName = d_children[i]->getName();
+		//We need to check if the current name is available or if the name + prefix is available.. Hopefully not both
+		if(childName == name || childName == d_windowPrefix + name)
 		{
 			return d_children[i];
 		}
 
-	}
+	} // for (size_t i = 0; i < child_count; ++i)
+
+	for(size_t i=0;i<child_count;i++)
+	{
+		Window* temp = d_children[i]->recursiveChildSearch(name);
+		if(temp)
+			return temp;
+	} // for(size_t i=0;i<child_count;i++)
 
 	throw UnknownObjectException("Window::getChild - The Window object named '" + name +"' is not attached to Window '" + d_name + "'.");
 }
 
+/***********************************************************************
+	returns a pointer to a child window... searches recursively for it
+	Use getChild() only. This function should only be used by getChild
+	to find any child windows within it. This function does not throw any
+	exceptions it will return NULL if nothing is found **WARNING**
+************************************************************************/
+Window* Window::recursiveChildSearch( const String& name ) const
+{
+	size_t child_count = getChildCount();
+
+	for (size_t i = 0; i < child_count; ++i)
+	{
+		String childName = d_children[i]->getName();
+		//We need to check if the current name is available or if the name + prefix is available.. Hopefully not both
+		if(childName == name || childName == d_windowPrefix + name)
+		{
+			return d_children[i];
+		}
+
+	} // for (size_t i = 0; i < child_count; ++i)
+
+	for(size_t i=0;i<child_count;i++)
+	{
+		Window* temp = d_children[i]->recursiveChildSearch(name);
+		if(temp)
+			return temp;
+	} // for(size_t i=0;i<child_count;i++)
+
+	return 0;
+}
+
 
 /*************************************************************************
 	return a pointer to the first attached child window with the
@@ -427,7 +470,7 @@ Window* Window::getChildRecursive(uint ID) const
 		{
 			return d_children[i];
 		}
-		
+
 		Window* tmp = d_children[i]->getChildRecursive(ID);
 		if (tmp != 0)
         {
@@ -500,7 +543,7 @@ bool Window::isAncestor(const String& name) const
 
 /*************************************************************************
 	return true if any Window with the given ID is some ancestor of
-	this Window.	
+	this Window.
 *************************************************************************/
 bool Window::isAncestor(uint ID) const
 {
@@ -522,7 +565,7 @@ bool Window::isAncestor(uint ID) const
 
 
 /*************************************************************************
-	return true if the specified Window is some ancestor of this Window.	
+	return true if the specified Window is some ancestor of this Window.
 *************************************************************************/
 bool Window::isAncestor(const Window* window) const
 {
@@ -636,7 +679,7 @@ Rect Window::getInnerRect(void) const
 
 /*************************************************************************
 	return a Rect object describing the Window area unclipped, in
-	screen space.	
+	screen space.
 *************************************************************************/
 Rect Window::getUnclippedPixelRect(void) const
 {
@@ -686,7 +729,7 @@ Rect Window::getUnclippedInnerRect_impl(void) const
 
 
 /*************************************************************************
-	check if the given position would hit this window.	
+	check if the given position would hit this window.
 *************************************************************************/
 bool Window::isHit(const Vector2& position) const
 {
@@ -839,6 +882,11 @@ void Window::setVisible(bool setting)
 *************************************************************************/
 void Window::activate(void)
 {
+    // exit if the window is not visible, since a hidden window may not be the
+    // active window.
+    if (!isVisible())
+        return;
+
 	// force complete release of input capture.
 	// NB: This is not done via releaseCapture() because that has
 	// different behaviour depending on the restoreOldCapture setting.
@@ -920,14 +968,14 @@ void Window::setFont(const String& name)
 	{
 		setFont(FontManager::getSingleton().getFont(name));
 	}
-	
+
 }
 
 
 /*************************************************************************
 	Add the named Window as a child of this Window.  If the Window is
 	already attached to a Window, it is detached before being added to
-	this Window.	
+	this Window.
 *************************************************************************/
 void Window::addChildWindow(const String& name)
 {
@@ -938,7 +986,7 @@ void Window::addChildWindow(const String& name)
 /*************************************************************************
 	Add the specified Window as a child of this Window.  If the Window
 	is already attached to a Window, it is detached before being added
-	to this Window.	
+	to this Window.
 *************************************************************************/
 void Window::addChildWindow(Window* window)
 {
@@ -990,7 +1038,7 @@ void Window::removeChildWindow(Window* window)
 /*************************************************************************
 	Remove the first child Window with the specified ID.  If there is more
 	than one attached Window objects with the specified ID, only the fist
-	one encountered will be removed.	
+	one encountered will be removed.
 *************************************************************************/
 void Window::removeChildWindow(uint ID)
 {
@@ -1021,24 +1069,28 @@ void Window::moveToFront()
 /*************************************************************************
 	Implementation of move to front
 *************************************************************************/
-void Window::moveToFront_impl(bool wasClicked)
+bool Window::moveToFront_impl(bool wasClicked)
 {
+    bool took_action = false;
+
 	// if the window has no parent then we can have no siblings
 	if (!d_parent)
 	{
 		// perform initial activation if required.
 		if (!isActive())
 		{
+            took_action = true;
             ActivationEventArgs args(this);
 			args.otherWindow = 0;
 			onActivated(args);
 		}
 
-		return;
+		return took_action;
 	}
 
 	// bring parent window to front of it's siblings
-    wasClicked ? d_parent->doRiseOnClick() : d_parent->moveToFront_impl(false);
+    took_action = wasClicked ? d_parent->doRiseOnClick() :
+                               d_parent->moveToFront_impl(false);
 
     // get immediate child of parent that is currently active (if any)
     Window* activeWnd = getActiveSibling();
@@ -1046,6 +1098,8 @@ void Window::moveToFront_impl(bool wasClicked)
     // if a change in active window has occurred
     if (activeWnd != this)
     {
+        took_action = true;
+
         // notify ourselves that we have become active
         ActivationEventArgs args(this);
         args.otherWindow = activeWnd;
@@ -1062,8 +1116,10 @@ void Window::moveToFront_impl(bool wasClicked)
     }
 
     // bring us to the front of our siblings
-    if (d_zOrderingEnabled)
+    if ((d_zOrderingEnabled) && !isTopOfZOrder())
     {
+        took_action = true;
+
         // remove us from our parent's draw list
         d_parent->removeWindowFromDrawList(*this);
         // re-attach ourselves to our parent's draw list which will move us in front of
@@ -1072,6 +1128,8 @@ void Window::moveToFront_impl(bool wasClicked)
         // notify relevant windows about the z-order change.
         onZChange_impl();
     }
+
+    return took_action;
 }
 
 
@@ -1478,7 +1536,7 @@ const Image* Window::getMouseCursor(bool useDefault) const
 
 /*************************************************************************
 	Set the mouse cursor image to be used when the mouse enters this
-	window.	
+	window.
 *************************************************************************/
 void Window::setMouseCursor(const String& imageset, const String& image_name)
 {
@@ -1487,7 +1545,7 @@ void Window::setMouseCursor(const String& imageset, const String& image_name)
 
 
 /*************************************************************************
-	Set the current ID for the Window.	
+	Set the current ID for the Window.
 *************************************************************************/
 void Window::setID(uint ID)
 {
@@ -1504,7 +1562,7 @@ void Window::setID(uint ID)
 
 /*************************************************************************
 	Set whether or not this Window will automatically be destroyed when
-	its parent Window is destroyed.	
+	its parent Window is destroyed.
 *************************************************************************/
 void Window::setDestroyedByParent(bool setting)
 {
@@ -1575,6 +1633,7 @@ void Window::addStandardProperties(void)
     addProperty(&d_mousePassThroughEnabledProperty);
     addProperty(&d_windowRendererProperty);
     addProperty(&d_lookNFeelProperty);
+    addProperty(&d_dragDropTargetProperty);
 
     // we ban some of these properties from xml for auto windows by default
     if (isAutoWindow())
@@ -1631,7 +1690,7 @@ bool Window::wantsMultiClickEvents(void) const
 
 /*************************************************************************
     Set whether this window will receive multi-click events or
-    multiple 'down' events instead.	
+    multiple 'down' events instead.
 *************************************************************************/
 void Window::setWantsMultiClickEvents(bool setting)
 {
@@ -1663,7 +1722,7 @@ float Window::getAutoRepeatDelay(void) const
     return d_repeatDelay;
 }
 
-    
+
 /*************************************************************************
     Return the current auto-repeat rate setting for this window.
 *************************************************************************/
@@ -1693,7 +1752,7 @@ void Window::setMouseAutoRepeatEnabled(bool setting)
         // FIXME: review an reworking - though such a change was
         // FIXME: beyond the scope of the bug-fix that originated this
         // FIXME: comment block.  PDT - 30/10/06
- 
+
         // TODO: Maybe add a 'setting changed' event for this?
     }
 
@@ -1714,7 +1773,7 @@ void Window::setAutoRepeatDelay(float delay)
 
 }
 
-    
+
 /*************************************************************************
     Set the current auto-repeat rate setting for this window.
 *************************************************************************/
@@ -1741,6 +1800,9 @@ void Window::update(float elapsed)
 	// update child windows
 	size_t child_count = getChildCount();
 
+	UpdateEventArgs e(this,elapsed);
+	fireEvent(EventWindowUpdated,e,EventNamespace);
+
 	for (size_t i = 0; i < child_count; ++i)
 	{
 		d_children[i]->update(elapsed);
@@ -1889,7 +1951,7 @@ void Window::setTooltip(Tooltip* tooltip)
     if (d_customTip && d_weOwnTip)
         WindowManager::getSingleton().destroyWindow(d_customTip);
 
-    // set new custom tooltip 
+    // set new custom tooltip
     d_weOwnTip = false;
     d_customTip = tooltip;
 }
@@ -1953,7 +2015,7 @@ bool Window::inheritsTooltipText(void) const
 {
     return d_inheritsTipText;
 }
-   
+
 void Window::setInheritsTooltipText(bool setting)
 {
     if (d_inheritsTipText != setting)
@@ -1964,17 +2026,19 @@ void Window::setInheritsTooltipText(bool setting)
     }
 }
 
-void Window::doRiseOnClick(void)
+bool Window::doRiseOnClick(void)
 {
     // does this window rise on click?
     if (d_riseOnClick)
     {
-        moveToFront_impl(true);
+        return moveToFront_impl(true);
     }
     else if (d_parent)
     {
-        d_parent->doRiseOnClick();
+        return d_parent->doRiseOnClick();
     }
+
+    return false;
 }
 
 void Window::setArea_impl(const UVector2& pos, const UVector2& size, bool topLeftSizing, bool fireEvents)
@@ -1987,7 +2051,7 @@ void Window::setArea_impl(const UVector2& pos, const UVector2& size, bool topLef
 
     // notes of what we did
     bool moved = false, sized;
-    
+
     // save original size so we can work out how to behave later on
     Size oldSize(d_pixelSize);
 
@@ -2032,7 +2096,7 @@ void Window::setArea_impl(const UVector2& pos, const UVector2& size, bool topLef
             // reset handled so 'sized' event can re-use (since  wo do not care about it)
             args.handled = false;
         }
-    
+
         if (sized)
         {
             onSized(args);
@@ -2183,12 +2247,12 @@ void Window::setLookNFeel(const String& look)
     WidgetLookManager& wlMgr = WidgetLookManager::getSingleton();
     if (!d_lookName.empty())
     {
-        /*
+        // Allow reset of look and feel
+        // NOTE: If you want to prevent this, replace the following lines with the commented exception one
         d_windowRenderer->onLookNFeelUnassigned();
         const WidgetLookFeel& wlf = wlMgr.getWidgetLook(d_lookName);
         wlf.cleanUpWidget(*this);
-        */
-        throw AlreadyExistsException("Window::setLookNFeel - There is already a look'n'feel assigned to the window '"+d_name+"'");
+        //throw AlreadyExistsException("Window::setLookNFeel - There is already a look'n'feel assigned to the window '"+d_name+"'");
     }
     d_lookName = look;
     Logger::getSingleton().logEvent("Assigning LookNFeel '" + look +"' to window '" + d_name + "'.", Informative);
@@ -2354,23 +2418,23 @@ int Window::writeChildWindowsXML(XMLSerializer& xml_stream) const
 
 bool Window::writeAutoChildWindowXML(XMLSerializer& xml_stream) const
 {
-    
+
     // just stop now if we are'nt allowed to write XML
     if (!d_allowWriteXML)
     {
         return false;
     }
-    // we temporarily output to this string stream to see if have to do the tag at all. // Make sure this stream does UTF-8 
+    // we temporarily output to this string stream to see if have to do the tag at all. // Make sure this stream does UTF-8
     std::ostringstream ss;
     XMLSerializer xml(ss);
     xml.openTag("AutoWindow");
-    // Create the XML Child Tree 
+    // Create the XML Child Tree
     // write out properties.
     writePropertiesXML(xml);
     // write out attached child windows.
     writeChildWindowsXML(xml);
     xml.closeTag();
-    if (xml.getTagCount() <= 1) 
+    if (xml.getTagCount() <= 1)
     {
         return false;
     }
@@ -2380,7 +2444,7 @@ bool Window::writeAutoChildWindowXML(XMLSerializer& xml_stream) const
     String suffix(getName(), getParent()->getName().length(), String::npos);
     // write name suffix attribute
     xml_stream.attribute("NameSuffix", suffix);
-    // Inefficient : do the XML serialization again 
+    // Inefficient : do the XML serialization again
     // write out properties.
     writePropertiesXML(xml_stream);
     // write out attached child windows.
@@ -2627,6 +2691,10 @@ void Window::onShown(WindowEventArgs& e)
 
 void Window::onHidden(WindowEventArgs& e)
 {
+    // first deactivate window if it is the active window.
+    if (isActive())
+        deactivate();
+
 	requestRedraw();
 	fireEvent(EventHidden, e, EventNamespace);
 }
@@ -2853,7 +2921,7 @@ void Window::onMouseLeaves(MouseEventArgs& e)
     {
         tip->setTargetWindow(0);
     }
-    
+
     fireEvent(EventMouseLeaves, e, EventNamespace);
 }
 
@@ -2887,9 +2955,9 @@ void Window::onMouseButtonDown(MouseEventArgs& e)
     }
 
     if (e.button == LeftButton)
-	{
-		doRiseOnClick();
-	}
+    {
+        e.handled |= doRiseOnClick();
+    }
 
     // if auto repeat is enabled and we are not currently tracking
     // the button that was just pushed (need this button check because
@@ -2907,8 +2975,7 @@ void Window::onMouseButtonDown(MouseEventArgs& e)
         }
     }
 
-
-	fireEvent(EventMouseButtonDown, e, EventNamespace);
+    fireEvent(EventMouseButtonDown, e, EventNamespace);
 }
 
 
@@ -2990,7 +3057,8 @@ void Window::setWindowRenderer(const String& name)
     WindowRendererManager& wrm = WindowRendererManager::getSingleton();
     if (d_windowRenderer != 0)
     {
-        /*
+        // Allow reset of renderer
+        // NOTE: If you want to prevent it, replace the following lines with the commented exception one
         if (d_windowRenderer->getName() == name)
         {
             return;
@@ -2998,8 +3066,7 @@ void Window::setWindowRenderer(const String& name)
         WindowEventArgs e(this);
         onWindowRendererDetached(e);
         wrm.destroyWindowRenderer(d_windowRenderer);
-        */
-        throw AlreadyExistsException("Window::setWindowRenderer - There is already a window renderer assigned to the window '"+d_name+"'");
+        //throw AlreadyExistsException("Window::setWindowRenderer - There is already a window renderer assigned to the window '"+d_name+"'");
     }
 
     if (!name.empty())
@@ -3117,7 +3184,11 @@ void Window::notifyClippingChanged(void)
 {
     d_screenRectValid = false;
     d_screenInnerRectValid = false;
-    
+    // make sure everything gets redrawn now that clipping has changed.
+    // NB: this way may not be not ideal, but invalidating the clipped rects
+    // only did not have the desired effect.
+    d_screenUnclippedInnerRectValid = false;
+
     // inform children that their clipped screen areas must be updated
     const size_t num = d_children.size();
     for (size_t i=0; i<num; ++i)
@@ -3135,7 +3206,7 @@ void Window::notifyScreenAreaChanged()
     d_screenUnclippedInnerRectValid = false;
     d_screenRectValid = false;
     d_screenInnerRectValid = false;
-    
+
     // inform children that their screen area must be updated
 	const size_t child_count = getChildCount();
 	for (size_t i = 0; i < child_count; ++i)
@@ -3154,4 +3225,82 @@ PropertySet::Iterator Window::getPropertyIterator() const
     return PropertySet::getIterator();
 }
 
+bool Window::isDragDropTarget() const
+{
+    return d_dragDropTarget;
+}
+
+void Window::setDragDropTarget(bool setting)
+{
+    d_dragDropTarget = setting;
+}
+
+//-----------------------------------------------------------------------
+void Window::setFalagardType(const String& type, const String& rendererType)
+{
+    // Retrieve the new widget look
+    const String separator("/");
+    String::size_type pos = type.find(separator);
+    String newLook(type, 0, pos);
+
+    // Check if old one is the same. If so, ignore since we don't need to do anything (type
+    // is already assigned)
+    pos = d_falagardType.find(separator);
+    String oldLook(d_falagardType, 0, pos);
+    if(oldLook == newLook)
+        return;
+
+    // Obtain widget kind
+    String widget(d_falagardType, pos + 1);
+
+    // Build new type (look/widget)
+    d_falagardType = newLook + separator + widget;
+
+    // Set new renderer
+    if(rendererType.length() > 0)
+        setWindowRenderer(rendererType);
+
+    // Apply the new look to the widget
+    setLookNFeel(type);
+}
+
+bool Window::isTopOfZOrder() const
+{
+    // if not attached, then always on top!
+    if (!d_parent)
+        return true;
+
+    // get position of window at top of z-order in same group as this window
+    ChildList::reverse_iterator pos = d_parent->d_drawList.rbegin();
+    if (!d_alwaysOnTop)
+    {
+        // find last non-topmost window
+        while ((pos != d_parent->d_drawList.rend()) && (*pos)->isAlwaysOnTop())
+            ++pos;
+    }
+
+    // return whether the window at the top of the z order is us
+    return *pos == this;
+}
+
+//----------------------------------------------------------------------------//
+void Window::insertText(const String& text, const String::size_type position)
+{
+    d_text.insert(position, text);
+
+    WindowEventArgs args(this);
+    onTextChanged(args);
+}
+    
+//----------------------------------------------------------------------------//
+void Window::appendText(const String& text)
+{
+    d_text.append(text);
+
+    WindowEventArgs args(this);
+    onTextChanged(args);
+}
+
+//----------------------------------------------------------------------------//
+
 } // End of  CEGUI namespace section
