@@ -1,34 +1,41 @@
-/************************************************************************
+/***********************************************************************
 	filename: 	CEGUIThumb.cpp
 	created:	25/4/2004
 	author:		Paul D Turner
 	
 	purpose:	Implements common parts of the Thumb base class widget
 *************************************************************************/
-/*************************************************************************
-    Crazy Eddie's GUI System (http://www.cegui.org.uk)
-    Copyright (C)2004 - 2005 Paul D Turner (paul@cegui.org.uk)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*************************************************************************/
+/***************************************************************************
+ *   Copyright (C) 2004 - 2006 Paul D Turner & The CEGUI Development Team
+ *
+ *   Permission is hereby granted, free of charge, to any person obtaining
+ *   a copy of this software and associated documentation files (the
+ *   "Software"), to deal in the Software without restriction, including
+ *   without limitation the rights to use, copy, modify, merge, publish,
+ *   distribute, sublicense, and/or sell copies of the Software, and to
+ *   permit persons to whom the Software is furnished to do so, subject to
+ *   the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be
+ *   included in all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+ *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+ *   OTHER DEALINGS IN THE SOFTWARE.
+ ***************************************************************************/
 #include "elements/CEGUIThumb.h"
+#include "CEGUICoordConverter.h"
 
 // Start of CEGUI namespace section
 namespace CEGUI
 {
 const String Thumb::EventNamespace("Thumb");
+const String Thumb::WidgetTypeName("CEGUI/Thumb");
+
 
 /*************************************************************************
 	Static Properties for this class
@@ -44,9 +51,9 @@ ThumbProperties::HorzRange	Thumb::d_horzRangeProperty;
 	Event name constants
 *************************************************************************/
 // generated internally by Window
-const String Thumb::EventThumbPositionChanged( (utf8*)"ThumbPosChanged" );
-const String Thumb::EventThumbTrackStarted( (utf8*)"ThumbTrackStarted" );
-const String Thumb::EventThumbTrackEnded( (utf8*)"ThumbTrackEnded" );
+const String Thumb::EventThumbPositionChanged( "ThumbPosChanged" );
+const String Thumb::EventThumbTrackStarted( "ThumbTrackStarted" );
+const String Thumb::EventThumbTrackEnded( "ThumbTrackEnded" );
 
 
 /*************************************************************************
@@ -63,7 +70,6 @@ Thumb::Thumb(const String& type, const String& name) :
 	d_horzMax(1.0f),
     d_beingDragged(false)
 {
-	addThumbEvents();
 	addThumbProperties();
 }
 
@@ -93,15 +99,15 @@ void Thumb::setVertRange(float min, float max)
 	d_vertMin = min;
 
 	// validate current position.
-	float cp = getYPosition();
+	float cp = getYPosition().asRelative(getParentPixelHeight());
 
 	if (cp < min)
 	{
-		setYPosition(min);
+		setYPosition(cegui_reldim(min));
 	}
 	else if (cp > max)
 	{
-		setYPosition(max);
+		setYPosition(cegui_reldim(max));
 	}
 
 }
@@ -112,6 +118,8 @@ void Thumb::setVertRange(float min, float max)
 *************************************************************************/
 void Thumb::setHorzRange(float min, float max)
 {
+    Size parentSize(getParentPixelSize());
+
 	// ensure min <= max, swap if not.
 	if (min > max)
 	{
@@ -124,31 +132,20 @@ void Thumb::setHorzRange(float min, float max)
 	d_horzMin = min;
 
 	// validate current position.
-	float cp = getXPosition();
+	float cp = getXPosition().asAbsolute(parentSize.d_width);
 
 	if (cp < min)
 	{
-		setXPosition(min);
+		setXPosition(cegui_absdim(min));
 	}
 	else if (cp > max)
 	{
-		setXPosition(max);
+		setXPosition(cegui_absdim(max));
 	}
 
 }
 
 
-/*************************************************************************
-	Add thumb specific events	
-*************************************************************************/
-void Thumb::addThumbEvents(void)
-{
-	addEvent(EventThumbPositionChanged);
-	addEvent(EventThumbTrackStarted);
-	addEvent(EventThumbTrackEnded);
-}
-
-
 /*************************************************************************
 	event triggered internally when the position of the thumb	
 *************************************************************************/
@@ -187,61 +184,47 @@ void Thumb::onMouseMove(MouseEventArgs& e)
 	// only react if we are being dragged
 	if (d_beingDragged)
 	{
+        Size parentSize(getParentPixelSize());
+
 		Vector2 delta;
 		float hmin, hmax, vmin, vmax;
 
-		// get some values as absolute pixel offsets
-		if (getMetricsMode() == Relative)
-		{
-			delta = relativeToAbsolute(screenToWindow(e.position));
+        delta = CoordConverter::screenToWindow(*this, e.position);
 
-			hmax = relativeToAbsoluteX_impl(d_parent, d_horzMax);
-			hmin = relativeToAbsoluteX_impl(d_parent, d_horzMin);
-			vmax = relativeToAbsoluteY_impl(d_parent, d_vertMax);
-			vmin = relativeToAbsoluteY_impl(d_parent, d_vertMin);
-		}
-		else
-		{
-			delta = screenToWindow(e.position);
+        hmin = d_horzMin;
+        hmax = d_horzMax;
+        vmin = d_vertMin;
+        vmax = d_vertMax;
 
-			hmin = d_horzMin;
-			hmax = d_horzMax;
-			vmin = d_vertMin;
-			vmax = d_vertMax;
-		}
-
-		// calculate amount of movement in pixels
+		// calculate amount of movement      
 		delta -= d_dragPoint;
+        delta.d_x /= parentSize.d_width;
+        delta.d_y /= parentSize.d_height;
 
 		//
 		// Calculate new (pixel) position for thumb
 		//
-		Point newPos(getAbsolutePosition());
+		UVector2 newPos(getPosition());
 
 		if (d_horzFree)
 		{
-			newPos.d_x += delta.d_x;
+			newPos.d_x.d_scale += delta.d_x;
 
 			// limit value to within currently set range
-			newPos.d_x = (newPos.d_x < hmin) ? hmin : (newPos.d_x > hmax) ? hmax : newPos.d_x;
+			newPos.d_x.d_scale = (newPos.d_x.d_scale < hmin) ? hmin : (newPos.d_x.d_scale > hmax) ? hmax : newPos.d_x.d_scale;
 		}
 
 		if (d_vertFree)
 		{
-			newPos.d_y += delta.d_y;
+			newPos.d_y.d_scale += delta.d_y;
 
 			// limit new position to within currently set range
-			newPos.d_y = (newPos.d_y < vmin) ? vmin : (newPos.d_y > vmax) ? vmax : newPos.d_y;
+			newPos.d_y.d_scale = (newPos.d_y.d_scale < vmin) ? vmin : (newPos.d_y.d_scale > vmax) ? vmax : newPos.d_y.d_scale;
 		}
 
 		// update thumb position if needed
-		if (newPos != getAbsolutePosition())
+		if (newPos != getPosition())
 		{
-			if (getMetricsMode() == Relative)
-			{
-				newPos = absoluteToRelative_impl(d_parent, newPos);
-			}
-
 			setPosition(newPos);
 
 			// send notification as required
@@ -271,12 +254,7 @@ void Thumb::onMouseButtonDown(MouseEventArgs& e)
 	{
 		// initialise the dragging state
 		d_beingDragged = true;
-		d_dragPoint = screenToWindow(e.position);
-
-		if (getMetricsMode() == Relative)
-		{
-			d_dragPoint = relativeToAbsolute(d_dragPoint);
-		}
+		d_dragPoint = CoordConverter::screenToWindow(*this, e.position);
 
 		// trigger tracking started event
 		WindowEventArgs args(this);
@@ -337,6 +315,15 @@ void Thumb::addThumbProperties(void)
 	addProperty(&d_horzFreeProperty);
 	addProperty(&d_vertRangeProperty);
 	addProperty(&d_horzRangeProperty);
+
+    // if we're an autowindow we ban some properties from XML
+    if (isAutoWindow())
+    {
+        banPropertyFromXML(&d_vertRangeProperty);
+        banPropertyFromXML(&d_horzRangeProperty);
+        banPropertyFromXML(&d_vertFreeProperty);
+        banPropertyFromXML(&d_horzFreeProperty);
+    }
 }
 
 
